@@ -13,8 +13,8 @@ auth = session.create_auth()
 
 resource = ListingResource(auth)
 
-inventory = resource.get_listing_inventory(1260997739)
-
+inventory = resource.get_listings_by_listing_ids(listing_ids=[1260997739, 533623129], includes="Inventory")
+print(inventory)
 """products = []
 print(inventory)
 for product in inventory.products:
