@@ -117,7 +117,7 @@ class ListingResource:
             "listing_ids":",".join(list(map(str, listing_ids))),
             "includes":includes
         }
-        endpoint = "https://openapi.etsy.com/v3/application/listings/batch"
+        endpoint = "listings/batch"
         
         response = self.auth.request(endpoint, params=params)
         return Response[Listing](**response)
\ No newline at end of file
